Crate opentalk_client

Crate opentalk_client 

OpenTalk client library

Structs

AuthenticatedClient
A client authenticated to the OIDC provider.
Client
A client for interfacing with the OpenTalk API.
OidcDeviceAuthorization
TODO
OidcDirectAccessGrant
TODO
OidcEndpoints
OAuth2/OIDC endpoints as pers spec
OidcTokenExchangeGrant
OIDC Token Exchange grant as per RFC8693

Enums

ClientError
The error that can result from requests sent by the client.
OidcAuthMethod
Supported auth methods to obtain OAuth2/OIDC grants
OidcGrant
A convenience facade, which will decide which kind of supported grant to use for user authentication depending on crate::OidcAuthMethod provided

Traits

Authorization
A trait for providing authorization tokens for client requests.