ClientError

Enum ClientError 

pub enum ClientError {
    Reqwest {
        source: ReqwestClientError,
    },
    Api {
        source: ApiError,
    },
    NoCompatibleApiVersion {
        url: Url,
        compatible_versions: String,
    },
    InvalidOidcUrl {
        url: String,
        source: ParseError,
    },
    InvalidUrlDiscovered {
        url: Url,
    },
}
The error that can result from requests sent by the client.

Variants



Reqwest

The http_request_derive library reqwest integration returned an error.

These are usually errors caused by either functionality in the reqwest crate, or when handling the data returned from reqwest.

They don’t indicate a non-successful HTTP status code, that is indicated by the ClientError::Api variant.

Fields

source: ReqwestClientError

The source error.



Api

The API returned an HTTP response with an HTTP status code which is considered non-successful.

Fields

source: ApiError

The source error.



NoCompatibleApiVersion

No compatible API version found under the well-known API endpoint.

Fields

url: Url

The URL under which the API endpint was looked up.

compatible_versions: String

The list of compatible API versions supported by this client implementation.



InvalidOidcUrl

The OpenTalk API returned an invalid OIDC URL.

Fields

url: String

The URL that was returned from the API.

source: ParseError

The error that was encountered when attempting to parse the URL.



InvalidUrlDiscovered

The OpenTalk API returned an OIDC URL which cannot be a base and is therefore invalid for usage in OIDC.

This happens e.g. for data: URLs.

Fields

url: Url

The invalid URL