OpenTalk client library
Structs
- Authenticated
Client - A client authenticated to the OIDC provider.
- Client
- A client for interfacing with the OpenTalk API.
- Oidc
Device Authorization - TODO
- Oidc
Direct Access Grant - TODO
- Oidc
Endpoints - OAuth2/OIDC endpoints as pers spec
- Oidc
Token Exchange Grant - OIDC Token Exchange grant as per RFC8693
Enums
- Client
Error - The error that can result from requests sent by the client.
- Oidc
Auth Method - Supported auth methods to obtain OAuth2/OIDC grants
- Oidc
Grant - A convenience facade, which will decide which kind of supported grant to use for user
authentication depending on
crate::OidcAuthMethodprovided
Traits
- Authorization
- A trait for providing authorization tokens for client requests.