pub enum ClientError {
Reqwest {
source: ReqwestClientError,
},
Api {
source: ApiError,
},
NoCompatibleApiVersion {
url: Url,
compatible_versions: String,
},
InvalidOidcUrl {
url: String,
source: ParseError,
},
InvalidUrlDiscovered {
url: Url,
},
}Expand description
The error that can result from requests sent by the client.
Variants
Reqwest
The http_request_derive library reqwest integration returned an error.
These are usually errors caused by either functionality in the
reqwest crate, or when handling the data returned from reqwest.
They don’t indicate a non-successful HTTP status code, that is indicated
by the ClientError::Api variant.
Fields
source: ReqwestClientErrorThe source error.
Api
The API returned an HTTP response with an HTTP status code which is considered non-successful.
NoCompatibleApiVersion
No compatible API version found under the well-known API endpoint.
Fields
InvalidOidcUrl
The OpenTalk API returned an invalid OIDC URL.
Fields
source: ParseErrorThe error that was encountered when attempting to parse the URL.
InvalidUrlDiscovered
The OpenTalk API returned an OIDC URL which cannot be a base and is therefore invalid for usage in OIDC.
This happens e.g. for data: URLs.